summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/extensions/nsplugin/src/qnp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/extensions/nsplugin/src/qnp.cpp')
-rw-r--r--experimental/tqtinterface/qt4/extensions/nsplugin/src/qnp.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/experimental/tqtinterface/qt4/extensions/nsplugin/src/qnp.cpp b/experimental/tqtinterface/qt4/extensions/nsplugin/src/qnp.cpp
index 987e6a878..5dc66849e 100644
--- a/experimental/tqtinterface/qt4/extensions/nsplugin/src/qnp.cpp
+++ b/experimental/tqtinterface/qt4/extensions/nsplugin/src/qnp.cpp
@@ -294,7 +294,7 @@ static jref plugin_java_class = 0;
** NPP_GetJavaClass is called during initialization to ask your plugin
** what its associated Java class is. If you don't have one, just return
** NULL. Otherwise, use the javah-generated "use_" function to both
** initialize your class and return it. If you can't tqfind your class, an
** error will be signalled by "use_" and will cause the Navigator to
** complain to the user.
*/
@@ -1688,12 +1688,12 @@ Boolean qnpxt_event_dispatcher( XEvent *event )
TQApplication::sendPostedEvents();
TQWidgetIntDict *mapper = &static_d->mapper;
- TQWidget* qnpxt = mapper->tqfind( event->xany.window );
- if ( !qnpxt && TQWidget::tqfind( event->xany.window) == 0 ) {
+ TQWidget* qnpxt = mapper->find( event->xany.window );
+ if ( !qnpxt && TQWidget::find( event->xany.window) == 0 ) {
// event is not for TQt, try Xt
Widget w = XtWindowToWidget( TQPaintDevice::x11AppDisplay(),
event->xany.window );
- while ( w && ! ( qnpxt = mapper->tqfind( XtWindow( w ) ) ) ) {
+ while ( w && ! ( qnpxt = mapper->find( XtWindow( w ) ) ) ) {
if ( XtIsShell( w ) ) {
break;
}
@@ -1796,7 +1796,7 @@ Boolean qnpxt_event_dispatcher( XEvent *event )
TQWidget *qw = 0;
Widget xw = XtWindowToWidget( TQPaintDevice::x11AppDisplay(),
event->xany.window );
- while ( xw && !( qw = mapper->tqfind( XtWindow( xw ) ) ) )
+ while ( xw && !( qw = mapper->find( XtWindow( xw ) ) ) )
xw = XtParent( xw );
while ( qw && qw != TQApplication::activeModalWidget() )
@@ -1933,7 +1933,7 @@ void TQNPXt::unregisterWidget( TQWidget* w )
void qnpxt_socknot_handler( XtPointer pointer, int *, XtInputId *id )
{
TQNPXt *eventloop = (TQNPXt *) pointer;
- TQSocketNotifier *socknot = static_d->socknotDict.tqfind( *id );
+ TQSocketNotifier *socknot = static_d->socknotDict.find( *id );
if ( ! socknot ) // this shouldn't happen
return;
eventloop->setSocketNotifierPending( socknot );
@@ -294,7 +294,7 @@ static jref plugin_java_class = 0;
** what its associated Java class is. If you don't have one, just return
** NULL. Otherwise, use the javah-generated "use_" function to both
-** initialize your class and return it. If you can't tqfind your class, an
+** initialize your class and return it. If you can't find your class, an
** error will be signalled by "use_" and will cause the Navigator to
** complain to the user.